package com.sun.net.ssl;

import java.security.NoSuchProviderException;
import java.security.NoSuchAlgorithmException;
import java.util.Iterator;
import sun.security.jca.Providers;
import java.security.Provider;

final class SSLSecurity
{
    private SSLSecurity() {
    }
    
    private static Provider.Service getService(String type, String algorithm) {
        Iterator<Provider> iterator = Providers.getProviderList().providers().iterator();
        while (iterator.hasNext()) {
            Provider.Service service = ((Provider)iterator.next()).getService(type, algorithm);
            if (service != null) {
                return service;
            }
            continue;
        }
        return null;
    }
    
    private static Object[] getImpl1(String str, String str2, Provider.Service service) throws NoSuchAlgorithmException {
        Provider provider = service.getProvider();
        String className = service.getClassName();
        Class<Object> clazz;
        try {
            ClassLoader classLoader = provider.getClass().getClassLoader();
            if (classLoader == null) {
                clazz = Class.forName(className);
            }
            else {
                clazz = classLoader.loadClass(className);
            }
        }
        catch (ClassNotFoundException ex) {
            throw new NoSuchAlgorithmException("Class " + className + " configured for " + str2 + " not found: " + ex.getMessage());
        }
        catch (SecurityException ex2) {
            throw new NoSuchAlgorithmException("Class " + className + " configured for " + str2 + " cannot be accessed: " + ex2.getMessage());
        }
        try {
            Object instance = null;
            Class<Object> forName;
            if ((forName = Class.forName("javax.net.ssl." + str2 + "Spi")) != null && checkSuperclass(clazz, forName)) {
                if (str2.equals("SSLContext")) {
                    instance = new SSLContextSpiWrapper(str, provider);
                }
                else if (str2.equals("TrustManagerFactory")) {
                    instance = new TrustManagerFactorySpiWrapper(str, provider);
                }
                else if (str2.equals("KeyManagerFactory")) {
                    instance = new KeyManagerFactorySpiWrapper(str, provider);
                }
                else {
                    throw new IllegalStateException("Class " + clazz.getName() + " unknown engineType wrapper:" + str2);
                }
            }
            else {
                Class<Object> forName2;
                if ((forName2 = Class.forName("com.sun.net.ssl." + str2 + "Spi")) != null && checkSuperclass(clazz, forName2)) {
                    instance = service.newInstance(null);
                }
            }
            if (instance != null) {
                return new Object[] { instance, provider };
            }
            throw new NoSuchAlgorithmException("Couldn't locate correct object or wrapper: " + str2 + " " + str);
        }
        catch (ClassNotFoundException cause) {
            IllegalStateException o = new IllegalStateException("Engine Class Not Found for " + str2);
            o.initCause(cause);
            throw o;
        }
    }
    
    static Object[] getImpl(String s, String type, String s2) throws NoSuchAlgorithmException, NoSuchProviderException {
        Provider.Service service;
        if (s2 != null) {
            Provider provider = Providers.getProviderList().getProvider(s2);
            if (provider == null) {
                throw new NoSuchProviderException("No such provider: " + s2);
            }
            service = provider.getService(type, s);
        }
        else {
            service = getService(type, s);
        }
        if (service == null) {
            throw new NoSuchAlgorithmException("Algorithm " + s + " not available");
        }
        return getImpl1(s, type, service);
    }
    
    static Object[] getImpl(String s, String type, Provider provider) throws NoSuchAlgorithmException {
        Provider.Service service = provider.getService(type, s);
        if (service == null) {
            throw new NoSuchAlgorithmException("No such algorithm: " + s);
        }
        return getImpl1(s, type, service);
    }
    
    private static boolean checkSuperclass(Class<?> superclass, Class<?> obj) {
        if (superclass == null || obj == null) {
            return false;
        }
        while (!superclass.equals(obj)) {
            superclass = superclass.getSuperclass();
            if (superclass != null) {
                continue;
            }
            return false;
        }
        return true;
    }
    
    static Object[] truncateArray(Object[] array, Object[] array2) {
        for (int i = 0; i < array2.length; ++i) {
            array2[i] = array[i];
        }
        return array2;
    }
}
